@@ -20,18 +20,18 @@ def build_config() -> dict[str, str]:
 
         # Package versions
         contourpy_version="1.3.3",
-        meson_version="1.9.2",
+        meson_version="1.7.2",
         mesonpy_version="0.18.0",
-        pybind11_version="3.0.1",
+        pybind11_version="3.0.0",
 
         # Misc meson settings
         meson_backend="ninja",
-        build_dir=r"/var/tmp/portage/dev-python/contourpy-1.3.3-r1/work/contourpy-1.3.3-python3_13/lib/contourpy/util",
-        source_dir=r"/var/tmp/portage/dev-python/contourpy-1.3.3-r1/work/contourpy-1.3.3/lib/contourpy/util",
+        build_dir=r"/var/tmp/portage/dev-python/contourpy-1.3.3/work/contourpy-1.3.3-python3_13/lib/contourpy/util",
+        source_dir=r"/var/tmp/portage/dev-python/contourpy-1.3.3/work/contourpy-1.3.3/lib/contourpy/util",
         cross_build="False",
 
         # Build options
-        build_options=r"-Dbuildtype=plain -Db_ndebug=if-release -Db_vscrt=md -Db_lto=false -Db_pch=false -Dwerror=false -Dprefix=/usr -Dlibdir=lib64 -Dlocalstatedir=/var/lib -Dsysconfdir=/etc -Dwrap_mode=nodownload -Dvsenv=True -Dbuild.pkg_config_path=/var/tmp/portage/dev-python/contourpy-1.3.3-r1/temp/python3.13/pkgconfig:/usr/share/pkgconfig -Dpkg_config_path=/var/tmp/portage/dev-python/contourpy-1.3.3-r1/temp/python3.13/pkgconfig:/usr/share/pkgconfig --native-file=/var/tmp/portage/dev-python/contourpy-1.3.3-r1/temp/meson.x86_64-pc-linux-gnu.ini --native-file=/var/tmp/portage/dev-python/contourpy-1.3.3-r1/work/contourpy-1.3.3-python3_13/meson-python-native-file.ini",
+        build_options=r"-Dbuildtype=plain -Db_ndebug=if-release -Db_vscrt=md -Db_lto=false -Db_pch=false -Dwerror=false -Dprefix=/usr -Dlibdir=lib64 -Dlocalstatedir=/var/lib -Dsysconfdir=/etc -Dwrap_mode=nodownload -Dvsenv=True -Dbuild.pkg_config_path=/var/tmp/portage/dev-python/contourpy-1.3.3/temp/python3.13/pkgconfig:/usr/share/pkgconfig -Dpkg_config_path=/var/tmp/portage/dev-python/contourpy-1.3.3/temp/python3.13/pkgconfig:/usr/share/pkgconfig --native-file=/var/tmp/portage/dev-python/contourpy-1.3.3/temp/meson.x86_64-pc-linux-gnu.amd64.ini --native-file=/var/tmp/portage/dev-python/contourpy-1.3.3/work/contourpy-1.3.3-python3_13/meson-python-native-file.ini",
         buildtype="plain",
         cpp_std="c++17",
         debug="False",
@@ -42,7 +42,7 @@ def build_config() -> dict[str, str]:
 
         # C++ compiler
         compiler_name="gcc",
-        compiler_version="15.2.1",
+        compiler_version="14.3.1",
         linker_id="ld.bfd",
         compile_command="x86_64-pc-linux-gnu-g++",
 
